.. _image_reducers:

======================
Image volume reduction
======================

Algorithms for reducing image size via volume selection and other methods.


API Reference
-------------

.. automodapi:: ctapipe.image.reducer


